@@ -37,12 +37,15 @@ class AdvancedWorker(Worker):
         if testing:
             init_kafka = False
 
+        create_consumer = init_kafka
+        create_producer = init_kafka
+
         super().__init__(
             kafka_broker_addr=kafka_opts.get("broker"),
             kafka_group_id=kafka_opts.get("group_id"),
             consumer_topic=kafka_opts.get("topic"),
-            create_consumer=init_kafka,
-            create_producer=init_kafka,
+            create_consumer=create_consumer,
+            create_producer=create_producer,
             sasl_opts=kafka_opts.get("sasl_opts"),
             consumer_opts={
                 "max_poll_interval_ms": 60000,
