@@ -212,6 +212,9 @@ class Worker:
                             f"redis client name set from: '{existing_name}' to: '{name_to_set}'"
                         )
                     await asyncio.sleep(60)
+                except asyncio.CancelledError:
+                    # at exit the long sleep will be cancelled and trigger empty error
+                    pass
                 except Exception as e:
                     logger.error(e)
 
